@@ -14,12 +14,12 @@ use strict;
 use warnings;
 
 package Pod::Markdown;
-# git description: v2.002-31-gf40f37b
+# git description: v2.002-36-g95e4807
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Convert POD to Markdown
-$Pod::Markdown::VERSION = '3.000';
-use Pod::Simple 3.14 (); # external links with text
+$Pod::Markdown::VERSION = '3.001';
+use Pod::Simple 3.26 (); # detected_encoding
 use parent qw(Pod::Simple::Methody);
 use Encode ();
 
@@ -1164,7 +1164,7 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 3.000
+version 3.001
 
 =head1 SYNOPSIS
 
